@@ -1,6 +1,6 @@
 #!/bin/sh
 
-cat > $ADTTMP/livetest.py <<EOF
+cat > $AUTOPKGTEST_TMP/livetest.py <<EOF
 from __future__ import print_function
 
 import io
@@ -19,14 +19,8 @@ print(fp.getvalue().decode('utf-8'), end='')
 
 EOF
 
-for py in `pyversions -i`
+for py in `py3versions -s`
 do
     $py --version
-    $py $ADTTMP/livetest.py
-done
-
-for py in `py3versions -i`
-do
-    $py --version
-    $py $ADTTMP/livetest.py
+    $py $AUTOPKGTEST_TMP/livetest.py
 done
